import {
  scaleLinear,
  scaleTime,
  extent,
  max,
  histogram as bin,
  timeYears,
  timeFormat
} from 'd3';
import { AxisBottom } from './AxisBottom';
import { AxisLeft } from './AxisLeft';
import { Marks } from './Marks';

const margin = { top: 0, right: 20, bottom: 70, left: 40 };
const xAxisLabelOffset = 54;
const yAxisLabelOffset = 30;

export const DateHistogram = ({ nuclearData, width, height }) => {
  const innerHeight = height - margin.top - margin.bottom;
  const innerWidth = width - margin.left - margin.right;

  const year = d => d.year; // x Value
  const xAxisLabel = 'Time';
  const yearScale = scaleLinear() // x Scale
    .domain(extent(nuclearData, year))
    .range([0, innerWidth]);

  const [start, stop] = yearScale.domain();

  const binnedNuclearData = bin()
    .value(year)
    .domain(yearScale.domain())
  	.thresholds(yearScale.ticks(stop - start))(nuclearData)
    .map(array => ({
      totalNuclearEvents: array.length,
      x0: array.x0,
      x1: array.x1
    }));
  console.log(binnedNuclearData);

  const yAxisLabel = 'Total Nuclear Events';
  const yScale = scaleLinear()
    .domain([0, max(binnedNuclearData, d => d.totalNuclearEvents)])
    .range([innerHeight, 0]);

  return (
    <>
      <rect width={width} height={height} fill='white' />
      <g transform={`translate(${margin.left},${margin.top})`}>
        <AxisBottom
          yearScale={yearScale}
          innerHeight={innerHeight}
          tickOffset={5}
        />
        <text
          className="axis-label-histogram"
          textAnchor="middle"
          transform={`translate(${-yAxisLabelOffset},${innerHeight /
            2}) rotate(-90)`}
        >
          {yAxisLabel}
        </text>
        <AxisLeft yScale={yScale} innerWidth={innerWidth} tickOffset={5} />
        <text
          className="axis-label"
          x={innerWidth / 2}
          y={innerHeight + xAxisLabelOffset}
          textAnchor="middle"
        >
          {xAxisLabel}
        </text>
        <Marks
          binnedNuclearData={binnedNuclearData}
          yearScale={yearScale}
          yScale={yScale}
          tooltipFormat={d => d}
          circleRadius={2}
          innerHeight={innerHeight}
        />
      </g>
    </>
  );
};
